# alfred3_dbtools

This module provides additional tools for working with databases in the context of alfred3 experiments (see [alfred3 on GitHub](https://github.com/ctreffe/alfred)).

## Installation

```bash
pip install alfred3_dbtools
```

## Usage

See [documentation](https://alfred3-dbtools.readthedocs.io/en/latest/).
